#
# fishing.R, 18 Jun 23
#
# Data from:
# WebAssembly versus JavaScript: Energy and Runtime Performance
# João De Macedo, Rui Abreu, Rui Pereira, João Saraiva


# The 10 short benchmarks
bb=read.csv("BenchmarkBrowser.csv", as.is=TRUE)

bb_mod=glm(log(Time) ~ Benchmark+Size+Browser+Language, data=bb)
summary(bb_mod)

# Just a Browser/Language interaction
bb_mod=glm(log(Time) ~ Benchmark+Size+Browser+Browser:Language, data=bb)
summary(bb_mod)

# A Browser/Language and Benchmark/Size interaction
bb_mod=glm(log(Time) ~ Benchmark+Benchmark:Size+Browser+Browser:Language, data=bb)
summary(bb_mod)

# Deviance Residuals: 
#      Min        1Q    Median        3Q       Max  
# -0.48400  -0.09410   0.00308   0.08670   0.79988  
# 
# Coefficients: (1 not defined because of singularities)
#                                       Estimate Std. Error  t value Pr(>|t|)    
# (Intercept)                          5.9915442  0.0385203  155.543  < 2e-16 ***
# Benchmarkfasta                      -0.0160268  0.0498897   -0.321    0.748    
# Benchmarkremoveduplicate            -2.3445343  0.0498897  -46.994  < 2e-16 ***
# Benchmarksortbead                   -2.6221724  0.0498897  -52.559  < 2e-16 ***
# Benchmarksortcircle                 -7.4396991  0.0498897 -149.123  < 2e-16 ***
# Benchmarksortingids                 -3.8745769  0.0498897  -77.663  < 2e-16 ***
# Benchmarksortingmerge               -5.4208242  0.0498897 -108.656  < 2e-16 ***
# Benchmarksortingnatural             -1.0783931  0.0498897  -21.616  < 2e-16 ***
# Benchmarksortingquick               -5.4645536  0.0498897 -109.533  < 2e-16 ***
# BrowserMicrosoftEdge                 0.3211749  0.0239662   13.401  < 2e-16 ***
# BrowserMozillaFirefox                0.1485095  0.0239662    6.197 9.52e-10 ***
# Benchmarkfannkuchredux:SizeMedium   -1.6506237  0.0498897  -33.085  < 2e-16 ***
# Benchmarkfasta:SizeMedium           -0.6177731  0.0498897  -12.383  < 2e-16 ***
# Benchmarkremoveduplicate:SizeMedium -0.7488500  0.0498897  -15.010  < 2e-16 ***
# Benchmarksortbead:SizeMedium        -0.9999956  0.0498897  -20.044  < 2e-16 ***
# Benchmarksortcircle:SizeMedium       1.8095869  0.0498897   36.272  < 2e-16 ***
# Benchmarksortingids:SizeMedium      -0.7035406  0.0498897  -14.102  < 2e-16 ***
# Benchmarksortingmerge:SizeMedium    -0.6542214  0.0498897  -13.113  < 2e-16 ***
# Benchmarksortingnatural:SizeMedium  -0.6862898  0.0498897  -13.756  < 2e-16 ***
# Benchmarksortingquick:SizeMedium    -0.6475187  0.0498897  -12.979  < 2e-16 ***
# Benchmarkfannkuchredux:SizeSmall    -6.7116586  0.0498897 -134.530  < 2e-16 ***
# Benchmarkfasta:SizeSmall            -1.3240703  0.0498897  -26.540  < 2e-16 ***
# Benchmarkremoveduplicate:SizeSmall  -1.4943195  0.0498897  -29.952  < 2e-16 ***
# Benchmarksortbead:SizeSmall         -1.9979422  0.0498897  -40.047  < 2e-16 ***
# Benchmarksortcircle:SizeSmall               NA         NA       NA       NA    
# Benchmarksortingids:SizeSmall       -1.5687378  0.0498897  -31.444  < 2e-16 ***
# Benchmarksortingmerge:SizeSmall     -1.4912212  0.0498897  -29.890  < 2e-16 ***
# Benchmarksortingnatural:SizeSmall   -1.4283084  0.0498897  -28.629  < 2e-16 ***
# Benchmarksortingquick:SizeSmall     -1.4692873  0.0498897  -29.451  < 2e-16 ***
# BrowserGoogleChrome:LanguageWASM     0.0003009  0.0239662    0.013    0.990    
# BrowserMicrosoftEdge:LanguageWASM   -0.2063428  0.0239662   -8.610  < 2e-16 ***
# BrowserMozillaFirefox:LanguageWASM   0.2786761  0.0239662   11.628  < 2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# (Dispersion parameter for gaussian family taken to be 0.03733467)
# 
#     Null deviance: 3982.444  on 779  degrees of freedom
# Residual deviance:   27.964  on 749  degrees of freedom
# AIC: -318.6
# 
# Number of Fisher Scoring iterations: 2

exp(coef(bb_mod))


# WasmBoy
wb=read.csv("WasmBoy.csv", as.is=TRUE)

wb_mod=glm(log(Time) ~ Scenario+Browser+Language, data=wb)
summary(wb_mod)

exp(coef(wb_mod))

#                      (Intercept) Scenariodinosofflineadventureall 
#                     220.79377584                       0.04773808 
#               Scenariopokemonall            Scenariosupermarioall 
#                       0.44193187                       0.43741372 
#        Scenariosupermariolandall          Scenariotobutobugirlall 
#                       0.44043812                       0.11517632 
#             BrowserMicrosoftEdge            BrowserMozillaFirefox 
#                       0.99581866                       1.36738214 
#                     LanguageWasm 
#                       0.83791699 


pdf=read.csv("PsODFKit.csv", as.is=TRUE)

pdf_mod=glm(log(Time) ~ Scenario+Browser*Language, data=pdf)
summary(pdf_mod)

# Call:
# glm(formula = log(Time) ~ Scenario + Browser:Language, data = pdf)
# 
# Deviance Residuals: 
#       Min         1Q     Median         3Q        Max  
# -0.109112  -0.019565  -0.001276   0.022701   0.153422  
# 
# Coefficients: (1 not defined because of singularities)
#                                    Estimate Std. Error t value Pr(>|t|)    
# (Intercept)                         4.35443    0.01079  403.39   <2e-16 ***
# Scenariohp40all                     0.62638    0.01079   58.03   <2e-16 ***
# Scenariohp80all                     1.21865    0.01079  112.89   <2e-16 ***
# Scenariopaperall                    0.33511    0.01079   31.04   <2e-16 ***
# Scenariopptall                      0.71153    0.01079   65.92   <2e-16 ***
# BrowserGoogleChrome:LanguageJS      0.22459    0.01182   18.99   <2e-16 ***
# BrowserMicrosoftEdge:LanguageJS     0.23257    0.01182   19.67   <2e-16 ***
# BrowserMozillaFirefox:LanguageJS    0.57392    0.01182   48.53   <2e-16 ***
# BrowserGoogleChrome:LanguageWasm    0.15647    0.01182   13.23   <2e-16 ***
# BrowserMicrosoftEdge:LanguageWasm   0.14271    0.01182   12.07   <2e-16 ***
# BrowserMozillaFirefox:LanguageWasm       NA         NA      NA       NA    
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# (Dispersion parameter for gaussian family taken to be 0.001747864)
# 
#     Null deviance: 29.5506  on 149  degrees of freedom
# Residual deviance:  0.2447  on 140  degrees of freedom
# AIC: -515.07

exp(coef(pdf_mod))

