#
# web_assembly-fishing.R, 17 Jun 23

# Data from:
# Comparing the Energy Efficiency of WebAssembly and JavaScript in Web Applications on Android Mobile Devices
# Max van Hasselt, Kevin Huijzendveld, Nienke Noort, Sasja de Ruijter, Tanjina Islam, Ivano Malavolta

wa=read.csv("EASE_2022_web_assembly.csv", as.is=TRUE)

wa$is_wasm=(wa$language == "wasm")
wa$is_firefox=(wa$browser == "firefox")

# The nonlinear regression model
wa_mod=nls(consumption ~ (1+a*is_wasm)*(1+b*is_firefox)*c, data=wa, start=c(a=0.1, b=0.1, c=100))
summary(wa_mod)


wa_mod=glm(log(consumption) ~ browser+language+algorithm, data=wa)
summary(wa_mod)

wa_mod=glm(log(consumption) ~ browser+language*algorithm, data=wa)
summary(wa_mod)

# Deviance Residuals: 
#      Min        1Q    Median        3Q       Max  
# -0.73966  -0.16285   0.01749   0.14747   1.66553  
# 
# Coefficients:
#                                 Estimate Std. Error t value Pr(>|t|)    
# (Intercept)                      4.58263    0.03555 128.902  < 2e-16 ***
# browserfirefox                  -0.34988    0.01836 -19.058  < 2e-16 ***
# languagewasm                    -2.80401    0.04857 -57.729  < 2e-16 ***
# algorithmhmm                    -1.10020    0.04857 -22.651  < 2e-16 ***
# algorithmlavamd                 -0.40000    0.04857  -8.235 6.99e-16 ***
# algorithmlud                     0.50015    0.04857  10.297  < 2e-16 ***
# algorithmnqueens                 0.09891    0.04857   2.036    0.042 *  
# algorithmnw                     -2.66400    0.04857 -54.846  < 2e-16 ***
# algorithmpage-rank               0.29842    0.04857   6.144 1.25e-09 ***
# languagewasm:algorithmhmm        2.32380    0.06869  33.830  < 2e-16 ***
# languagewasm:algorithmlavamd     2.64647    0.06869  38.527  < 2e-16 ***
# languagewasm:algorithmlud        0.73939    0.06869  10.764  < 2e-16 ***
# languagewasm:algorithmnqueens    1.91393    0.06869  27.863  < 2e-16 ***
# languagewasm:algorithmnw         4.36591    0.06869  63.558  < 2e-16 ***
# languagewasm:algorithmpage-rank  1.07231    0.06869  15.611  < 2e-16 ***
# ---
# Signif. codes:  0 ‘***’ 0.001 ‘**’ 0.01 ‘*’ 0.05 ‘.’ 0.1 ‘ ’ 1
# 
# (Dispersion parameter for gaussian family taken to be 0.07077748)
# 
#     Null deviance: 898.447  on 839  degrees of freedom
# Residual deviance:  58.391  on 825  degrees of freedom
# AIC: 176.18


